<?php

namespace App\Helper;

use \Illuminate\Support\Facades\Cache;

class General
{
    public function rateLimit($key, $limit = 10)
    {
        return !\Illuminate\Support\Facades\RateLimiter::attempt($key, $limit, function () {
        });
    }

    public function recaptchaFails()
    {
        if (config('setting.google_recaptcha')) {
            $recaptcha = @$_REQUEST['g-recaptcha-response'];
            $url = 'https://www.google.com/recaptcha/api/siteverify?secret=' . config('setting.google_recaptcha_secret_key') . '&response=' . $recaptcha;
            $response = @file_get_contents($url);
            $response = @json_decode($response);
            return @$response->success ? false : true;
        } else {
            return true;
        }
    }

    public function getClientIp()
    {
        return '182.70.125.98';
        // return '54.219.192.57';
        $ipaddress = '';
        if (isset($_SERVER['HTTP_CLIENT_IP']))
            $ipaddress = $_SERVER['HTTP_CLIENT_IP'];
        else if (isset($_SERVER['HTTP_X_FORWARDED_FOR']))
            $ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
        else if (isset($_SERVER['HTTP_X_FORWARDED']))
            $ipaddress = $_SERVER['HTTP_X_FORWARDED'];
        else if (isset($_SERVER['HTTP_FORWARDED_FOR']))
            $ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
        else if (isset($_SERVER['HTTP_FORWARDED']))
            $ipaddress = $_SERVER['HTTP_FORWARDED'];
        else if (isset($_SERVER['REMOTE_ADDR']))
            $ipaddress = $_SERVER['REMOTE_ADDR'];
        else
            $ipaddress = '';
        return $ipaddress;
    }

    public function getIpInfo($ip = '', $decode = 1)
    {
        if ($ip == '') {
            $ip = $this->getClientIp();
        }
        $key = 'ip_info:' . $ip;
        $result = Cache::get($key);
        if (!$result) {
            $result = @file_get_contents('https://code.tribital.in/ipinfo/index.php?ip=' . $ip);
            Cache::add($key, $result, 86400);
        }
        if ($result && $decode) {
            $result = @json_decode($result);
            if($decode==2){
                if(@$result->country_name){
                    $result =@$result->city.' , '.@$result->region.' , '.@$result->country_name;
                }else{
                    $result ='';
                }
            }
        }
        return $result;
    }

    public function getIpInfoCountry($ip = '')
    {
        if ($ip = '') {
            $ip = $this->getClientIp();
        }
        $key = 'ip_info:' . $ip;
        $data = Cache::get($key);
        if ($data) {
            return $data;
        }
        $result =  @file_get_contents('https://code.tribital.in/ipinfo_country/index.php?ip=' . $ip);
        Cache::add($key, $result, 86400);
        return $result;
    }

    function deviceName($device_name)
    {
        $result = (new \WhichBrowser\Parser($device_name));
        if ($result && isset($result->browser->name)) {
            return @$result->browser->name . ' on ' . @$result->os->name;
        } else {
            return '';
        }
    }

    public function getMetaTags()
    {
        return (new \App\Models\SeoMeta())->getMetaTags();
    }

    public function getAllSettings()
    {
        return (new \App\Models\Setting())->getAllSettings();
    }

    function getfilePath($type = 1)
    {
        $path = '';
        switch ($type) {
            case 1:
                $path = 'profile/';
                break;
            case 2:
                $path = 'setting/';
                break;
            case 3:
                $path = 'blog/';
                break;
        }
        return $path;
    }

    function getNoFile($type = 1)
    {
        $file = '';
        switch ($type) {
            case 1:
                $file = 'default/no-image.jpg';
                break;
            case 2:
                $file = 'default/no-image.jpg';
                break;
            case 3:
                $file = 'default/no-image.jpg';
                break;
        }
        return \Illuminate\Support\Facades\Storage::url($file);
    }

    function getFileUrl($file, $type = 1, $subDir = '')
    {
        if ($file) {
            $subDir = $subDir ? $subDir . '/' : '';
            $path = $this->getfilePath($type) . $subDir;
            $storage = new \Illuminate\Support\Facades\Storage();
            if ($storage::has($path . $file)) {
                return $storage::url($path . $file);
            }
        }
        return $this->getNoFile($type);
    }

    function deleteFile($file, $type = 1, $subDir = '')
    {
        if ($file) {
            $subDir = $subDir ? $subDir . '/' : '';
            $path = $this->getfilePath($type) . $subDir;
            $storage = new \Illuminate\Support\Facades\Storage();
            if ($storage::has($path . $file)) {
                $storage::delete($path . $file);
            }
        }
    }
    
    public function validate($data, $rule, $customMessages = [])
    {
        $data = $this->validateData($data, $rule);
        $model = $validator = \Illuminate\Support\Facades\Validator::make($data, $rule, $customMessages);
        if ($validator->fails()) {
            return ['status' => 0, 'message' => $this->getError($validator)];
        } else {
            return ['status' => 1];
        }
    }
    public function validateData($data, $rule)
    {
        $fields = $this->getFields($rule);
        foreach ($fields as $row) {
            if (!isset($data[$row])) {
                $data[$row] = '';
            }
        }
        return $data;
    }
    public function getFields($rule)
    {
        $fields = [];
        foreach ($rule as $row) {
            $fieldRow = isset($row[0]) ? $row[0] : '';
            if (is_array($fieldRow)) {
                foreach ($fieldRow as $frow) {
                    $fields[] = $frow;
                }
            } else if ($fieldRow) {
                $fields[] = $fieldRow;
            }
        }
        return $fields;
    }

    public function validateFilesMultiple($fieldName, $isRequired = false, $allowExt = [], $maxFileSize = 100000000)
    {
        $result = ['status' => 1, 'data' => []];
        if (isset($_FILES[$fieldName]) && isset($_FILES[$fieldName]['tmp_name'][0]) && $_FILES[$fieldName]['tmp_name'][0] != '') {
            $files = $_FILES[$fieldName];
            foreach ($files['tmp_name'] as $key => $row) {
                $file = [
                    'name' => $files['name'][$key],
                    'type' => $files['type'][$key],
                    'tmp_name' => $files['tmp_name'][$key],
                    'size' => $files['size'][$key],
                ];
                $fileResult = $this->checkFile($file, $isRequired, $allowExt, $maxFileSize);
                if (!$fileResult['status']) {
                    $result['status'] = 0;
                }
                $result['data'][] = $fileResult['data'];
            }
        } else {
            if ($isRequired) {
                $result['status'] = 0;
            }
        }
        return $result;
    }
    public function fileUpload($fieldName, $type = 1)
    {
        if (isset($_FILES[$fieldName]) && $_FILES[$fieldName]['tmp_name'] != '') {
            $file = $_FILES[$fieldName];
            return $this->upload($file, $type);
        }
        return ['status' => 0, 'message' => 'File not found'];
    }
    function upload($file, $type = 1, $subDir = '')
    {
        // dd($file);
        $filePath = $this->getfilePath($type) . $subDir;
        $fileResult = \Illuminate\Support\Facades\Storage::put($filePath, $file);
        if ($fileResult) {
            return str_replace($filePath . '/', '', $fileResult);
        } else {
            return '';
        }
    }

    public static function sendMail($to, $subject, $view, $data = [])
    {
        try {
            $body = view($view, $data)->render();
            \Mail::send('email.layouts.container', ['body' => $body], function ($m) use ($to, $subject) {
                $m->from(config('setting.mail_from_address'), config('setting.mail_from_name'));
                $m->to($to)->subject($subject);
            });
        } catch (\Exception $e) {
            \Log::error('Email Failed : ' . $to . ' : ' . $subject);
        }
    }

    public function getError($validator)
    {
        $errors = $validator->messages()->all();
        return isset($errors[0]) ? $errors[0] : 'Something went wrong';
    }

    //custom functions

    public function slugify($title)
    {
        // Convert the string to lowercase
        $slug = strtolower($title);

        // Replace spaces and special characters with hyphens
        $slug = preg_replace('/[^a-z0-9]+/', '-', $slug);

        // Remove leading and trailing hyphens
        $slug = trim($slug, '-');

        // Return the generated slug
        return $slug;
    }
}
