<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Validator;
use App\Helper\General;

class AdminController extends Controller
{
    public function index()
    {
        return view('admin/admin/index');
    }
    public function list(Request $request)
    {
        return response()->json((new User())->listAdmin($request->all()));
    }
    public function create()
    {
        return view('admin/admin/create');
    }

    public function update(Request $request)
    {
        $id = $request->id;
        $admin = User::where('id', $id)->first();
        return view('admin/admin/update', compact('admin'));
    }

    public function save(Request $request)
    {
        $id = $request->id;
        $rules = [
            'first_name' => 'required|regex:/^[\pL\s\-]+$/u|max:255',
            'last_name' => 'required|regex:/^[\pL\s\-]+$/u|max:255',
            'email' => 'required|email|required|regex:/(.+)@(.+)\.(.+)/i',
            'status' => 'required',
        ];
        if (!$id) {
            $rules['email'] = 'required|email|max:255|unique:admin';
            $rules['password']='required';
        }
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return response()->json(['status' => 0, 'message' => $this->general->getError($validator)]);
        }
        $model = new User();
        if ($id) {
            $model = User::find($id);
        } else {
            $model = new User();
            $model->created_at = time();
        }
        if (isset($image) && $image) {
            $model->image = $image;
        }
        if ($request->hasFile('image')) {
            $uploadResult = (new General())->upload($request->input('image'), 1);
            if($uploadResult){
                if ($model->image) {
                    (new General())->deleteFile($model->image, 1);
                }
                $model->image = $uploadResult;
            }
        }
        $model->first_name = $request['first_name'];
        $model->last_name = $request['last_name'];
        $model->email = $request['email'];
        $model->status = $request['status'];
        $model->type = 0;
        $model->password = $request->input('password');
        $model->updated_at = time();
        if ($request->input('password')) {
            $model->password = (new User)->encryptPassword($request->input('password'));
        }
        $model->save();
        if ($id) {
            return response()->json(['status' => 1, 'message' => 'Admin Updated successfully.', 'next' => 'admin']);
        } else {
            return response()->json(['status' => 1, 'message' => 'Admin Created successfully.', 'next' => 'admin']);
        }
    }

    public function view(Request $request)
    {
        $id =  $request->id;
        $admin = User::where('id', $id)->first();
        return view('admin/admin/view', compact('admin'));
    }

}
