<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\User;

class UserController extends Controller
{
    public function index()
    {
        return view('admin/user/index');
    }

    public function list(Request $request)
    {
        return response()->json((new User())->list($request->all()));
    }

    public function create()
    {
        return view('admin/user/create');
    }

    public function update(Request $request)
    {
        $model = User::find($request->id);
        if(!$model){
            return redirect('admin/user')->withError('error','No data found');
        }
        return view('admin/user/update', compact('model'));
    }

    public function save(Request $request)
    {
        $id = $request->input('id');
        $rules=[
            'first_name' => 'required|max:255',
            'last_name' => 'required|max:255',
            'email' => 'required|email|max:255',
            'image'=>'mimes:jpeg,jpg,png,gif,webp|max:10000',
            'country' => 'required',
            'status' => 'required'
        ];
        if(!$id){
            $rules['email']='required|email|max:255|unique:user'; 
        }
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return response()->json(['status' => 0, 'message' => $this->general->getError($validator)]);
        }
        $id = $request->id;
        if ($id) {
            $model = User::find($id);
        } else {
            $model = new User();
        }
        if($request->hasFile('image')){
            $image = $this->general->upload($request->file('image'),1);
            if ($image) {
                if($model->image){
                    $this->general->deleteFile($model->image,1);
                }
                $model->image = $image;
            }
        }
        $model->first_name = $request->input('first_name');
        $model->last_name = $request->input('last_name');
        $model->email = $request->input('email');
        $model->password = $request->input('password');
        $model->country = $request->input('country');
        $model->status = $request->input('status');
        if($request->input('password')){
            $model->password = (new User)->encryptPassword($request->input('password'));
        }
        $model->save();

        return response()->json(['status' => 1, 'message' => $id?'Data Updated successfully.':'Data Created successfully.', 'next' => 'admin/user']);
    }
    public function view(Request $request)
    {
        $model = User::find($request->input('id'));
        if(!$model){
            return redirect('admin/user')->withError('error','No data found');
        }
        return view('admin/user/view', compact('model'));
    }

    public function delete(Request $request)
    {
        $model = User::find($request->input('id'));
        if (!$model) {
            return response()->json(['status' => 0, 'message' => 'No data found']);
        }
        $model->delete();
        return response()->json(['status' => 1, 'message' => 'Data Deleted successfully.', 'next' => 'table_refresh']);
    }
}
