<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use App\Models\Note;

class NoteController extends Controller
{
    public function index()
    {
        return view('note/index');
    }

    public function list(Request $request)
    {
        return response()->json((new Note())->list($request->all(), auth()->id()));
    }

    public function create()
    {
        return view('note/create');
    }

    public function view(Request $request)
    {
        $model = Note::find($request->input('id'));
        if(!$model){
            return redirect('note')->withError('error','No data found');
        }
        return view('note/view', compact('model'));
    }
    public function update(Request $request)
    {
        $model = Note::find($request->input('id'));
        if(!$model){
            return redirect('note')->withError('error','No data found');
        }
        return view('note/update', compact('model'));
    }

    public function save(Request $request)
    {
        $userId = auth()->id();
        $validator = Validator::make($request->all(), [
            'title' => 'required',
            'note' => 'required',
        ]);
        if ($validator->fails()) {
            return response()->json(['status' => 0, 'message' => $this->general->getError($validator)]);
        }
        $id = $request->input('id');
        if ($id) {
            $model = Note::find($id);
        } else {
            $model = new Note();
            $model->user_id = $userId;
        }
        $model->title = $request['title'];
        $model->note = $request['note'];
        $model->save();

        return response()->json(['status' => 1, 'message' => $id?'Data Updated successfully':'Data Create successfully.', 'next' => 'note']);
    }

    public function delete(Request $request)
    {
        $model = Note::find($request->input('id'));
        if (!$model) {
            return response()->json(['status' => 0, 'message' => 'Not found']);
        }
        $model->delete();
        return response()->json(['status' => 1, 'message' => 'Deleted successfully.', 'next' => 'table_refresh']);
    }
}
