<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Concerns\HasUlids;
use App\Helper\Pagination;
use App\Helper\General;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;

class Device extends Model
{
    use HasUlids;

    protected $table = 'device';
    protected $primaryKey = 'id';
    protected $keyType = 'string';
    public $incrementing = false;
    public $timestamps = true;
    protected $dateFormat = 'U';

    protected $fillable = [
        'user_id', 'device_uid','session_id', 'type', 'remember_token','remember_expire_at','client','ip','created_at','status_tfa'
    ];

    public function generateAuthtoken()
    {
        return \Illuminate\Support\Str::random(64);
    }

    public function login($userId,$remember=1)
    {
        $deviceUid=@$_COOKIE['dtoken'];
        if(!$deviceUid){
            return false;
        }
        $client=@$_SERVER['HTTP_USER_AGENT'];
        $time=time();
        $device=self::where(['device_uid'=>$deviceUid])->first();
        // dd($device);
        if(!$device){
            $device=new Device();
            $device->device_uid = $deviceUid;
            
        }
        $device->user_id = $userId;
        
        if($remember){
            $device->remember_token = $this->generateAuthtoken();
            $device->remember_expire_at = $time+(config('setting.device_expire_days')*24*60*60);
            \Illuminate\Support\Facades\Cookie::queue('user_remember_token', $device->remember_token, 60 * 24 * 30);
        }else{
            $device->remember_expire_at = 0;
        }

        $general = new General();
        $ip = $general->getClientIp();
        $device->ip =$ip;
        $device->client =$client;
        $device->session_id= session()->getId();
        
        $device->save();
        return $device;
    }

    public function logout(){
        $deviceUid=@$_COOKIE['dtoken'];
        if(!$deviceUid){
            return false;
        }
        $device=self::where(['device_uid'=>$deviceUid])->first();
        if($device){
            $device->user_id=0;
            $device->remember_token='';
            $device->remember_expire_at=0;
            $device->session_id='';
            $device->save();
        }
    }

    public function forceLogout($id){
        $device=self::where('id',$id)->first();
        if($device){
            $sessionDriver=config('session.driver');
            if($sessionDriver=='file'){
                if(session()->getId()==$device->session_id){
                    auth()->logout();
                }else{
                    try{
                        Session::getHandler()->destroy($device->session_id);
                        unlink(config('session.files').'/'.$device->session_id);
                    }catch(\Exception $e){}
                }
            }elseif($sessionDriver=='database'){
                DB::table('sessions')->where('id', $device->session_id)->delete();
            }
            $device->user_id=0;
            $device->remember_token='';
            $device->remember_expire_at=0;
            $device->session_id='';
            $device->save();
        }
    }

    public function list($postData, $userId)
    {
        $query = DB::table('device')->select(['device.*','sessions.last_activity'])
        ->where('device.user_id', $userId)
        ->where('remember_expire_at','>',time())
        ->leftJoin('sessions','sessions.id','device.session_id');
        $searchText = isset($postData['search']['value']) ? $postData['search']['value'] : '';
        if (strlen($searchText) > 2) {
            $searchText = '%' . $searchText . '%';
            $query->orwhere("device.client", 'like', $searchText);
            $query->orwhere("device.type", 'like', $searchText);
        }
        $general = new General();
        $result = (new Pagination())->getDataTable($query, $postData);
        foreach ($result['data'] as $key => $row) {
            $result['data'][$key]->location=$general->getIpInfo($row->ip,2);
            $result['data'][$key]->client = (new General())->deviceName($row->client).' '.($row->device_uid==@$_COOKIE['dtoken']?' (This Device)':'');  
            $result['data'][$key]->last_activity = date(config('setting.date_time_format'), @$row->last_activity ?$row->last_activity:$row->updated_at);
            $result['data'][$key]->action='<button onclick="app.confirmAction(this);" data-action="'.route('profile/logout').'" data-id="'.$row->id.'" class="btn btn-danger" title="logout"><i class="fa fa-sign-out-alt nav-icon"></i> Log out</button>';
        }
        return $result;
    }

    public function listAdmin($postData)
    {
        $query = DB::table('device')->select(['device.updated_at as updated_at','device.id','device.ip','device.device_uid','device.client','device.id as deviceId','device.type As type', 'user.first_name','user.last_name'])
            ->leftJoin('user', 'user.id', '=', 'device.user_id')
            ->where('remember_expire_at','>',time())
            ->leftJoin('sessions','sessions.id','device.session_id');
            
        $searchText = isset($postData['search']['value']) ? $postData['search']['value'] : '';
        if (strlen($searchText) > 2){
            $searchText = '%' . $searchText . '%';
            $query->where(DB::raw('CONCAT(user.first_name, " ",user.last_name)  '), 'like', $searchText);
            $query->orwhere("device.client", 'like', $searchText);
            $query->orwhere("device.type", 'like', $searchText);
        }
        $result = (new Pagination())->getDataTable($query, $postData);
        $general = new General();
        foreach ($result['data'] as $key => $row) {
            $result['data'][$key]->first_name = $row->first_name.' '.$row->last_name;
            $result['data'][$key]->location=$general->getIpInfo($row->ip,2);
            $result['data'][$key]->client = (new General())->deviceName($row->client).' '.($row->device_uid==@$_COOKIE['dtoken']?' (This Device)':'');  
            $result['data'][$key]->last_activity = date(config('setting.date_time_format'), @$row->last_activity ?$row->last_activity:$row->updated_at);
            $result['data'][$key]->action='<button Onclick="app.confirmAction(this);" data-action="'.route('admin/device/logout').'" data-id="'.$row->deviceId.'" class="btn btn-danger" title="logout"><i class="fa fa-sign-out-alt nav-icon"></i> Log out</button>';
        }
        return $result;
    }
    
    public function deviceType($type){
        if ($type == 0) {
            $type = '<span class="">User</span>';
        } else if ($type == 1) {
            $type = '<span class="">Admin</span>';
        } 
        return $type;
    }

}