<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Concerns\HasUlids;
use App\Helper\Pagination;
use App\Helper\General;
use Illuminate\Support\Facades\DB;

class Log extends Model
{
    use HasUlids;

    protected $table = 'log';
    protected $primaryKey = 'id';
    protected $keyType = 'string';
    public $incrementing = false;
    public $timestamps = true;
    protected $dateFormat = 'U';

    protected $fillable = [
        'user_id', 'user_type', 'type','ip','client', 'created_at', 'updated_at'
    ];

    public function add($userId, $type)
    { 
        if(!config('setting.save_user_log')){
            return false;
        }
        $client=@$_SERVER['HTTP_USER_AGENT'];
        $general = new General();
        $activity = new Log();
        $ip = $general->getClientIp();
        $activity->ip = $ip;
        $activity->client = $client;

        $activity->user_id = $userId;
        $activity->type = $type;
        $activity->device_uid = @$_COOKIE['dtoken'];
        
        $activity->created_at = time();
        $activity->updated_at = time();

        $activity->save();
    }

    public function sendNewDeviceMail($user){
        // send email if new device and location is fidderent
        if(!config('setting.save_user_log')){
            return false;
        }
        $device_uid = @$_COOKIE['dtoken'];
        $device_uid=$device_uid?$device_uid:'';
        $client=@$_SERVER['HTTP_USER_AGENT'];
        $general = new General();
        $ip = $general->getClientIp();
        $activityObj = new Log();
        $lastDevice = $activityObj->where('user_id', $user->id)
            ->whereRaw('( device_uid=? or ip=? )',[$device_uid,$ip])
            ->first();
        if(!$lastDevice){
            $ipInfo=$general->getIpInfo($ip);
            $general->sendMail($user->email, 'Logged in With new Device | ' . config('setting.app_name'), 'email/logged_diff_location', [
                'name' => $user->first_name . ' ' . $user->last_name,
                'ip'=>$ip,
                'client'=>$client,
                'ip_info'=>$ipInfo
            ]);
        }
    }

    public function listAdmin($postData)
    {
        $query = DB::table('log')->select(['log.created_at as created_at', 'log.type As type','log.ip', 'log.client', 'user.first_name', 'user.last_name'])
            ->join('user', 'user.id', '=', 'log.user_id');
        $searchText = isset($postData['search']['value']) ? $postData['search']['value'] : '';
        if (strlen($searchText) > 2){
            $searchText = '%' . $searchText . '%';
            $query->where('user.first_name', 'like', $searchText);
            $query->where('user.last_name', 'like', $searchText);
            $query->orwhere("log.type", 'like', $searchText);
            $query->orwhere("log.client", 'like', $searchText);
        }
        
        $result = (new Pagination())->getDataTable($query, $postData);
        $general = new General();
        foreach ($result['data'] as $key => $row) {
            $deviceName = (new General())->deviceName($row->client);
            $result['data'][$key]->first_name = $row->first_name.' '.$row->last_name;
            $result['data'][$key]->location=$general->getIpInfo($row->ip,2);
            $result['data'][$key]->device = $deviceName;
            $result['data'][$key]->type = $this->getType($row->type);
            $result['data'][$key]->created_at = date(config('setting.date_time_format'), $row->created_at);
        }
        
        return $result;
    }

    public function list($postData,$userId)
    {
        $query = DB::table('log')->select('*')->where('user_id', $userId);
        $searchText = isset($postData['search']['value']) ? $postData['search']['value'] : '';
        if (strlen($searchText) > 2) {
            $searchText = '%' . $searchText . '%';
            $query->where("data", 'like', $searchText);
            $query->orwhere("type", 'like', $searchText);
        }
        $result = (new Pagination())->getDataTable($query, $postData);
        $general = new General();
        foreach ($result['data'] as $key => $row) {
            $result['data'][$key]->location=$general->getIpInfo($row->ip,2);
            $result['data'][$key]->client = (new General())->deviceName($row->client).' '.($row->device_uid==@$_COOKIE['dtoken']?' (This Device)':'');  
            $result['data'][$key]->type = $this->getType($row->type);
            $result['data'][$key]->created_at = date(config('setting.date_time_format'), $row->created_at); 
        }
        return $result;
    }
    
    public function getUserType($type){
        if($type==0){
            $type = '<span class="">User</span>';
        }else if($type == 1) {
            $type = '<span class="">Admin</span>';
        } 
        return $type;
    }
    
    public function getType($type){
        if ($type == 0) {
            $type = '<span class="">login failed</span>';
        } else if ($type == 1) {
            $type = '<span class="">login success</span>';
        } 
        else if ($type==3){
            $type = '<span class="">Register</span>';
        }
        else if ($type == 4){
            $type = '<span class="">login with otp</span>';
        }
        else if ($type==5){
            $type = '<span class="">login with social media</span>';
        }
        else{
            $type = '<span class="">login with remeber</span>';
        }
        return $type;
    }
}
