String.prototype.replaceAll = function (search, replacement) {
    return this.replace(new RegExp(search, "g"), replacement);
};

(function ($) {
    $.fn.serializeObject = function () {
        var self = this,
            json = {},
            push_counters = {},
            patterns = {
                validate:/^[a-zA-Z][a-zA-Z0-9_]*(?:\[(?:\d*|[a-zA-Z0-9_]+)\])*$/,
                key: /[a-zA-Z0-9_]+|(?=\[\])/g,
                push: /^$/,
                fixed: /^\d+$/,
                named: /^[a-zA-Z0-9_]+$/,
            };
        this.build = function (base, key, value) {
            base[key] = value;
            return base;
        };
        this.push_counter = function (key) {
            if (push_counters[key] === undefined) {
                push_counters[key] = 0;
            }
            return push_counters[key]++;
        };
        $.each($(this).serializeArray(), function () {
            // Skip invalid keys
            if (!patterns.validate.test(this.name)) {
                return;
            }
            var k,
                keys = this.name.match(patterns.key),
                merge = this.value,
                reverse_key = this.name;
            while ((k = keys.pop()) !== undefined) {
                // Adjust reverse_key
                reverse_key = reverse_key.replace(new RegExp("\\[" + k + "\\]$"),"");
                if (k.match(patterns.push)) {
                    merge = self.build(
                        [],
                        self.push_counter(reverse_key),
                        merge
                    );
                }else if (k.match(patterns.fixed)) {
                    merge = self.build([], k, merge);
                }else if (k.match(patterns.named)) {
                    merge = self.build({}, k, merge);
                }
            }
            json = $.extend(true, json, merge);
        });
        return json;
    };
})(jQuery);

var app = {
    dataToHtml: function (htmlString, data) {
        $.each(data, function (index, value) {
            htmlString = htmlString.replaceAll("__" + index + "__", value);
        });
        return htmlString.replaceAll(/\__(.+?)\__/g, "");
    },
    renderHtmldata: function (template, data) {
        var html = "";
        if (template) {
            $.each(data, function (index, value) {
                html = html + app.dataToHtml(template, value);
            });
        }
        return html;
    },
    showModalView: function (url) {
        $.ajax({
            url: url,
            method: "get",
            success: function (response) {
                app.setModalContent(response);
                app.showModal();
                app.runDocumentReady();
            },
        });
    },
    setModalContent: function (html) {
        app.commonModel.find("#common-modal-content").html(html);
    },
    showModal: function () {
        !app.commonModel.is(":visible") && app.commonModel.modal("show");
    },
    hideModal: function () {
        app.commonModel.is(":visible") && app.commonModel.modal("hide");
    },
    showLoading: function () {
        swal.showLoading();
    },
    hideLoading() {
        swal.hideLoading();
    },
    ajaxForm: function (form) {
        form = $(form);
        app.ajaxRequest(form.attr("action"), form.serialize());
    },
    ajaxPost: function (url, postData) {
        postData[CSRF_NAME] = CSRF_TOKEN;
        app.ajaxRequest(url, postData);
    },
    ajaxAction: function (obj) {
        var $obj = $(obj);
        var postData = {};
        if ($obj.data("id")) {
            postData.id = $obj.data("id");
        }
        postData[CSRF_NAME] = CSRF_TOKEN;
        app.ajaxRequest($obj.data("action"), postData);
    },
    confirmAction: function (obj) {
        var $obj = $(obj);
        Swal.fire({
            title: "Are you sure?",
            text: "You won't be able to revert this!",
            icon: "warning",
            showCancelButton: true,
            confirmButtonText: "Yes",
        }).then((result) => {
            if (result.value) {
                var postData = { id: $obj.data("id") };
                postData[CSRF_NAME] = CSRF_TOKEN;
                app.ajaxRequest($obj.data("action"), postData);
            }
        });
    },
    ajaxCallback: false,
    nextAction: function (next) {
        if (next == "reload") {
            window.location.reload();
        } else if (next == "refresh") {
            router.reload();
        } else if (next == "table_refresh") {
            datatableObj.ajax.reload();
        } else if (next == "hide_modal") {
            app.hideModal();
        } else if (next == "hide_modal_refresh") {
            app.hideModal();
            router.reload();
        } else if (next == "nothing") {
        } else if (next != "") {
            router.navigateTo(next);
        }
    },
    ajaxSuccess: function (response) {
        if (response.status) {
            if (response.message) {
                Swal.fire("", response.message, "success").then(function (
                    result
                ) {
                    app.nextAction(response.next);
                });
            } else {
                app.hideLoading();
                app.nextAction(response.next);
            }
        } else {
            if (response.message) {
                Swal.fire("Warning", response.message, "warning");
            } else {
                app.hideLoading();
            }
        }
    },
    ajaxError: function (e) {
        Swal.fire(
            "Oops!",
            "Something went wrong. Pelase Try after sometime.",
            "error"
        );
    },
    ajaxRequest: function (url, postData) {
        app.showLoading();
        $.ajax({
            url: url,
            method: "post",
            data: postData,
            dataType: "json",
            success: app.ajaxSuccess,
            error: app.ajaxError,
        });
    },
    ajaxGet: function (url) {
        app.showLoading();
        $.ajax({
            url: url,
            method: "get",
            dataType: "json",
            success: app.ajaxSuccess,
            error: app.ajaxError,
        });
    },
    ajaxFileForm: function (form) {
        form = $(form);
        app.showLoading();
        $.ajax({
            url: form.attr("action"),
            method: "post",
            data: new FormData(form[0]),
            dataType: "json",
            processData: false,
            contentType: false,
            success: app.ajaxSuccess,
            error: app.ajaxError,
        });
    },
    addCSS: function (urls) {
        $.each(urls, function (index, url) {
            if (!$('link[href="' + url + '"]').length) {
                $("body").append('<link href="' + url + '" rel="stylesheet">');
            }
        });
    },
    addJS: function (urls) {
        $.each(urls, function (index, url) {
            if (!$('script[src="' + url + '"]').length) {
                $("body").append('<script src="' + url + '"></script>');
            }
        });
    },
    loadScript:function( url, callback ) {
        if ($('script[src="' + url + '"]').length) {
            callback();
            return false;
        }
        var script = document.createElement( "script" )
        script.type = "text/javascript";
        if(script.readyState) {  // only required for IE <9
          script.onreadystatechange = function() {
            if ( script.readyState === "loaded" || script.readyState === "complete" ) {
              script.onreadystatechange = null;
              callback();
            }
          };
        } else {  //Others
          script.onload = function() {
            callback();
          };
        }
      
        script.src = url;
        document.getElementsByTagName( "head" )[0].appendChild( script );
    },
    setCookie: function (cname, cvalue, exdays) {
        var d = new Date();
        d.setTime(d.getTime() + exdays * 24 * 60 * 60 * 1000);
        var expires = "expires=" + d.toUTCString();
        document.cookie = cname + "=" + cvalue + "; " + expires + ";path=/";
    },
    getCookie: function (cname) {
        var name = cname + "=";
        var ca = document.cookie.split(";");
        for (var i = 0; i < ca.length; i++) {
            var c = ca[i];
            while (c.charAt(0) == " ") {
                c = c.substring(1);
            }
            if (c.indexOf(name) == 0) {
                return c.substring(name.length, c.length);
            }
        }
        return "";
    },

    validateFile: function (file) {
        var re = /(\.jpg|\.jpeg|\.bmp|\.gif|\.png)$/i;
        if (!re.exec(file.name)) {
            return { status: 0, message: "File is not valid" };
        }
        return { status: 1, message: "" };
    },
    updateDataTableUrl: function (url) {
        datatableObj.settings().ajax.url(url).load();
    },
    encodeData:function(data){
        console.log(data);
        try{
            return btoa(JSON.stringify(data)).replaceAll('=','');
        }catch(e){
            return '';
        }
    },
    decodeData:function(data){
        try{
            return JSON.parse(atob(data));
        }catch(e){
            return {};
        }
    },
    setUrl:function(url,params){
        if(params){
            var paramStringArray=[];
            var urlData=url.split('?');
            if(url.match('\\?')){
                url=urlData[0];
                urlData=urlData[1];
                if(urlData){
                    $.each(urlData.split('&'),function(ke,vl){
                        var paramd=vl.split('=');
                        oldKey=paramd[0];
                        oldValue=paramd[1];
                        var exist=false;
                        $.each(params,function(key,value){
                            if(oldKey==key){
                                exist=true;
                            }
                        })
                        if(!exist){
                            paramStringArray.push(oldKey+'='+oldValue);
                        }
                    })
                }
            }
            $.each(params,function(key,value){
                paramStringArray.push(key+'='+value);
            })
            url+='?'+paramStringArray.join('&');
        }
        window.history.pushState({},'',url);
    },
    makeid: function (length) {
        let result = "";
        const characters =
            "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
        const charactersLength = characters.length;
        let counter = 0;
        while (counter < length) {
            result += characters.charAt(
                Math.floor(Math.random() * charactersLength)
            );
            counter += 1;
        }
        return result;
    },
    init: function () {
        if (!this.getCookie("dtoken")) {
            this.setCookie("dtoken", this.makeid(64), 365);
        }

        this.commonModel = $("#common-modal");
        app.runDocumentReady();

        var tz = Intl.DateTimeFormat().resolvedOptions().timeZone;
        if (this.getCookie("tz") != tz) {
            this.setCookie("tz", tz, 30);
        }
    },
    runDocumentReady: function (){
        if(documentReadyFunctions){
            $.each(documentReadyFunctions,function(index,cb){
                cb();
            });
            documentReadyFunctions=[];
        }
    }
};

$(document).ready(function () {
    app.init();
});

class View {
    target = "";
    init(target) {
        this.target = $(target);
    }
    load(url) {
        var target = this.target;
        target.html("Loading...");
        $.ajax({
            url: url,
            method: "get",
            success: function (response) {
                target.html(response);
                router.checkLinks();
                app.runDocumentReady();
            },
            error: function (e) {
                Swal.fire(
                    "Oops!",
                    "Something went wrong. Pelase Try after sometime.",
                    "error"
                );
            },
        });
    }
}

class Pagination {
    ajaxUrl = "";
    ajaxContainer = false;
    postData = {
        offset: 0,
        limit: 10,
        _token: CSRF_TOKEN,
        sort: {field:'',direction:'asc'},
        search: "",
        filter: {},
        filter_extra: {},
    };
    init(url) {
        this.ajaxUrl = url;
        this.ajaxContainer = $("#pagination-ajax-container");
        this.loadData();
    }
    initPagination(url, ajaxContainer) {
        this.ajaxUrl = url;
        this.ajaxContainer = $(ajaxContainer);
        this.loadData();
    }
    loadData() {
        var _this = this;
        this.ajaxContainer.html("Loading...");
        $.ajax({
            method: "post",
            url: this.ajaxUrl,
            data: this.postData,
            success: function (response) {
                _this.ajaxContainer.html(response);
                router.checkLinks();
            },
            error: function (e) {
                _this.ajaxContainer.html(
                    "Something Went wrong! Please Try after sometime"
                );
            },
        });
    }
    loadList(offset) {
        this.postData.offset = offset;
        this.loadData();
        app.setUrl(window.location.href,{offset:offset});
    }
    sort(field,direction) {
        this.postData.sort.field = field;
        this.postData.sort.direction = direction;
        this.loadList(0);
        app.setUrl(window.location.href,{sort:field+'-'+direction});
    }
    search(value) {
        this.postData.search= value;
        this.loadList(0);
        app.setUrl(window.location.href,{search:value,offset:0});        
    }  
    filter(key,value) {
        this.postData.filter[key]=value;
        this.loadList(0);
        app.setUrl(window.location.href,{filter:app.encodeData(this.postData.filter)});
    }
    filterFormSubmit(form) {
        this.postData.filter = $(form).serializeObject();
        this.loadList(0);
        app.setUrl(window.location.href,{filter:app.encodeData(this.postData.filter)});
    }
    advanceFilterFormSubmit(form) {
        this.postData.filter_extra = $(form).serializeObject();
        this.loadList(0);
        app.setUrl(window.location.href,{filter_extra:app.encodeData(this.postData.filter_extra)});
    }  
}

class ImageCrop {
    cropTarget = false;
    cropperObj = false;
    uploadPath = "";
    cropperConfig = {
        aspectRatio: 1,
        cropBoxResizable: false,
        autoCropArea: 1
    };
    init(id, uploadPath) {
        this.cropTarget = document.getElementById(id);
        this.uploadPath = uploadPath;
    }
    setConfig(config) {
        this.cropperConfig = config;
    }
    setCropper() {
        this.cropperObj = new Cropper(this.cropTarget, this.cropperConfig);
        $(".image-crop-action").show();
    }
    setCropFile(file) {
        if (this.cropperObj) {
            this.cropperObj.destroy();
        }
        var _this = this;
        var reader = new FileReader();
        reader.onload = function (e) {
            _this.cropTarget.src = e.target.result;
            _this.setCropper();
        };
        reader.readAsDataURL(file);
    }
    uploadImage() {
        if (!this.cropperObj) {
            Swal.fire("Warning", "Please select image", "warning");
            return false;
        }
        app.showLoading();
        var _uploadPath = this.uploadPath;
        this.urltoFile(
            this.cropperObj.getCroppedCanvas().toDataURL(),
            "image.png",
            "image/png"
        ).then(function (file) {
            var formData = new FormData();
            formData.append(CSRF_NAME, CSRF_TOKEN);
            formData.append("image", file);
            $.ajax({
                url: _uploadPath,
                method: "post",
                data: formData,
                dataType: "json",
                processData: false,
                contentType: false,
                success: app.ajaxSuccess,
                error: app.ajaxError,
            });
        });
    }
    urltoFile(url, filename, mimeType) {
        return fetch(url)
            .then(function (res) {
                return res.arrayBuffer();
            })
            .then(function (buf) {
                return new File([buf], filename, { type: mimeType });
            });
    }
    getFile(){
        return this.urltoFile(
            this.cropperObj.getCroppedCanvas().toDataURL(),
            "image.png",
            "image/png"
        )
    }
    rotateLeft() {
        if (this.cropperObj) {
            this.cropperObj.rotate(90);
        }
    }
    rotateRight() {
        if (this.cropperObj) {
            this.cropperObj.rotate(-90);
        }
    }
}

/**custom functions */
function initCKEditorMin(editorElement) {
    ClassicEditor.create(editorElement, {
        toolbar: {
            items: [
                "exportPDF",
                "exportWord",
                "|",
                "findAndReplace",
                "selectAll",
                "|",
                "heading",
                "|",
                "bold",
                "italic",
                "strikethrough",
                "underline",
                "code",
                "subscript",
                "superscript",
                "removeFormat",
                "|",
                "bulletedList",
                "numberedList",
                "todoList",
                "|",
                "outdent",
                "indent",
                "|",
                "undo",
                "redo",
                "fontSize",
                "fontFamily",
                "fontColor",
                "fontBackgroundColor",
                "highlight",
                "|",
                "alignment",
                "|",
                "link",
                "insertImage",
                "blockQuote",
                "insertTable",
                "codeBlock",
                "htmlEmbed",
                "|",
                "specialCharacters",
                "horizontalLine",
                "pageBreak",
                "|",
                "textPartLanguage",
            ],
            shouldNotGroupWhenFull: true,
        },
    })
        .then((editor) => {
            //console.log( editor );
        })
        .catch((error) => {
            //console.error( error );
        });
}

function setDarkMode(obj) {
    var value = app.getCookie("dark_mode");
    app.setCookie("dark_mode", value == "1" ? "0" : "1", 30);
    if (value != "1") {
        $(obj).find("i").addClass("fa-moon").removeClass("fa-sun");
        $("body").addClass("dark-mode");
    } else {
        $(obj).find("i").addClass("fa-sun").removeClass("fa-moon");
        $("body").removeClass("dark-mode");
    }
}

function previewImage(input){
    $($(input).data('preview')).attr('src',URL.createObjectURL(input.files[0]));
}