@extends('layouts.blank')
@section('title')
Login to Your Account
@endsection
@section('content')
<div class="login-box">
    <div class="login-logo">
        <b>{{config('setting.app_name')}}</b>
    </div>
    <!-- /.login-logo -->
    <div class="card">
        <div class="card-body login-card-body">
            <p class="login-box-msg">Sign in to start your session</p>
            {{ view('common/flash_message')}}

            <form action="{{route('login-process')}}" method="post" class="ajax-form">
                {{ csrf_field() }}
                <div class="input-group mb-3">
                    <input type="email" name="email" class="form-control" value="{{old('email')}}" placeholder="Email" required="required">
                    <div class="input-group-append">
                        <div class="input-group-text">
                            <span class="fas fa-envelope"></span>
                        </div>
                    </div>
                </div>
                <div class="input-group mb-3" {{$errors->has('password')?'has-error':''}}>
                    <input type="password" name="password" class="form-control" placeholder="Password" required="required">
                    <div class="input-group-append">
                        <div class="input-group-text">
                            <span class="fas fa-lock"></span>
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-8">
                        <div class="form-check">
                            <input name="remember" type="checkbox" class="form-check-input" id="exampleCheck1" checked>
                            <label class="form-check-label" for="exampleCheck1">Remember Me</label>
                        </div>
                    </div>

                    <!-- /.col -->
                    <div class="col-4">
                        <button type="submit" class="btn btn-primary btn-block btn-flat">Sign In</button>
                    </div>
                    <!-- /.col -->
                </div>
            </form>
            <div class="social-auth-links text-center mb-3">
                @if(config('setting.user_login_with_otp') == 1)
                <a href="{{route('otp/login')}}" class="btn btn-block btn-success noroute">Login with Otp </a>
                @endif
                @if(config('setting.google_login') == 1)
                <a href="{{ route('oauth/login',['type'=>'google']) }}" class="btn btn-block btn-danger noroute">
                    <i class="fab fa-google-plus mr-2"></i> Sign in using Google+
                </a>
                @endif
            </div>
            <p class="mb-1">
                <center>
                    <p>New user?<a href="{{ route('register') }}" class="text-center"> <B>Register Now </B></a></p>
                </center>
            </p>
            <center><a href="{{ route('site/password-forgot') }}">Forgot password ?</a></center>

        </div>
        <!-- /.login-card-body -->
    </div>
</div>
<!-- /.login-box -->
<script>
    documentReady(function() {
        $('.ajax-form').validate({
            rules: {
                email: {
                    required: true,
                    email: true
                },
                password: {
                    minlength: 6,
                    maxlength: 32,
                    required: true,
                },
            },
            messages: {
                email: {
                    required: "Please Enter Your Email.",
                    email: "Please enter a valid email address."
                },
                password: {
                    required: "Please Enter Your Password",
                    minlength: "Please enter at least 6 characters.",
                    maxlength: "Please enter no more than 32 characters.",
                }
            },
        })
    })
</script>
@endsection