<?php
namespace App\Helper;

class Pagination
{
    public function getData($query, $postData, $paginationUrl = 1)
    {
        $response = [];
        $response['limit'] = isset($postData['limit']) ? (int)$postData['limit'] : 20;
        if($response['limit']>100){$response['limit']=100;}
        $response['offset'] = isset($postData['offset']) ? (int)$postData['offset'] : 0;
        if($paginationUrl){
            $response['total'] = $query->count();
        }

        if (isset($postData['sort']) && $postData['sort'] && isset($postData['sort']['field']) && $postData['sort']['field']) {
            $query->orderBy($postData['sort']['field'], $postData['sort']['direction']);
        }
        
        $query->offset($response['offset']);
        $query->limit($response['limit']);
        $response['data'] = $query->get();
        if ($paginationUrl==1) {
            $response['paginationLinks'] = $this->getPaginationAjaxLinks($response['total'], $response['limit'], $response['offset']);
        } else if ($paginationUrl) {
            $response['paginationLinks'] = $this->getPaginationLinks($response['total'], $response['limit'], $response['offset'], $paginationUrl);
        }
        return $response;
    }

    public function getDataTable($query, $postData)
    {
        $response = [];
        $result = $this->setPaginationDataTable($postData);
        $total = $query->count();
        $response['recordsTotal'] = $total ? (int)$total : 0;
        if ($result['orderByField'] != '' && $result['orderBy'] != '') {
            $query->orderBy($result['orderByField'], $result['orderBy']);
        }
        $query->offset($result['offset']);
        $query->limit($result['limit']);
        $response['data'] = $query->get();
        $response['recordsFiltered'] = $response['recordsTotal'];
        $response['draw'] = $result['draw'];
        return $response;
    }

    public function setPaginationDataTable($data)
    {
        $array['draw'] = isset($data['draw']) ? $data['draw'] : 0;
        $array['limit'] = isset($data['length']) ? $data['length'] : 20;
        $array['offset'] = isset($data['start']) ? $data['start'] : 0;
        $array['orderByField'] = '';
        $array['orderBy'] = '';
        if (isset($data['order'])) {
            for ($i = 0, $ien = count($data['order']); $i < $ien; $i++) {
                $columnIdx = intval($data['order'][$i]['column']);
                $requestColumn = $data['columns'][$columnIdx];
                $array['orderByField'] = isset($requestColumn['data']) ? $requestColumn['data'] : '';
                $array['orderBy'] = '';
                if ($requestColumn['orderable'] == 'true') {
                    $array['orderBy'] = $data['order'][$i]['dir'] === 'asc' ? 'ASC' : 'DESC';
                }
            }
        }
        return $array;
    }

    public function getPaginationLinks($total = 0, $limit = 20, $offset = 0, $paginationUrl)
    {
        if ($total && $total > $limit) {
        } else {
            return '';
        }
        if ($paginationUrl == 1) {
            $paginationUrl = explode('?', $_SERVER['REQUEST_URI'])[0];
        }
        $currentPage = round($offset / $limit) + 1;
        $lastPage = round($total / $limit) + 1;
        return view('common/pagination', ['currentPage' => $currentPage, 'lastPage' => $lastPage, 'total' => $total, 'limit' => $limit, 'offset' => $offset, 'paginationUrl' => $paginationUrl]);
    }

    public function getPaginationAjaxLinks($total = 0, $limit = 20, $offset = 0)
    {
        if ($total && $total > $limit) {
        } else {
            return '';
        }
        $currentPage = round($offset / $limit) + 1;
        $lastPage = ceil($total / $limit);
        return view('common/pagination_ajax', ['currentPage' => $currentPage, 'lastPage' => $lastPage, 'total' => $total, 'limit' => $limit, 'offset' => $offset]);
    }
}
