<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Storage;
use App\Helper\General;
use App\Helper\Pagination;
use App\Models\Blog;
use App\Models\BlogTag;
use App\Models\BlogCategory;

class BlogController extends Controller
{
    public function index()
    {
        return view('admin/blog/index');
    }
    public function list(Request $request){
		return response()->json((new Blog())->listAdmin($request->all(), auth()->id()));
	}

    public function create()
    {
         $bcategory =BlogCategory::All();
        //  dd($bcategory);
         return view('admin/blog/create',compact('bcategory'));
    }

    public function update($id){
        if($id){
            $blog = Blog::find($id);
        }
        $bcategory =BlogCategory::All();
        return view('admin/blog/update',compact('blog','bcategory'));
    }
    public function save(Request $request){
		$id = $request->id;
		if ($request->isMethod('post')) {
			$validator = Validator::make($request->all(), [
				'title' => 'required',
				'description' => 'required',
				'tag' => 'required',
				'category' => 'required',
				'image'=> 'required',
			]);
			if ($validator->fails()) {
				return response()->json(['status' => 0, 'message' => $this->general->getError($validator)]);
			}
			$blogObj = new Blog();
			$blogObj->image = $request->image;
			$blog = Blog::find($request->id);
			if ($blogObj['image']) {
				$validator = Validator::make($request->all(), [
					'image' => 'mimes:jpg,png,jpeg,webp',

				]);
			}
			if (empty($blog['image'])) {
				$validator = Validator::make($request->all(), [
					'image' => 'required|mimes:jpg,png,jpeg,webp',
					'title' => 'required',
					'description' => 'required',
					'tag' => 'required',
					'category' => 'required',
				]);
			}
			if ($validator) {
				$tag = $request->tag;
				$tag = json_decode($tag);
				$totaltags = [];
				foreach ($tag as $key => $val) {
					foreach ($val as $tagkey => $tagval) {
						$totaltags[] = $tagval;
					}
				}
				$tagvalue = implode(",", $totaltags);
				$tagvalue = str_replace(".", "", $tagvalue);
				if ($request->id) {
					$blogObj = Blog::find($request->id);
				} else {
					$blogObj->created_at = time();
				}
				$slug = (new General())->slugify($request->title);
				$blogObj->title = $request->title;
				$blogObj->slug = $slug . '-' . $id;
				$blogObj->description = $request->description;
				$blogObj->tags = $tagvalue;
				$blogObj->blog_category_id = $request->category;
				if ($request->hasFile('image')) {
					if ($request->old_image) {
						$deleteFile = (new General())->deleteFile($request->old_image, 3);
					}
					// dd($request->all());
					$uploadResult = (new General())->upload($request->file('image'), 3);
					// (new General())->fileUpload('image',3);
					$blogObj->image = $uploadResult;
				}
				$blogObj->updated_at = time();
				$blogObj->save();
				$tags = explode(",", $tagvalue);
				foreach ($tags as $key => $val) {
					$blogTag = BlogTag::where('title', $val)->first();
					if (!$blogTag) {
						$bTag = new BlogTag();
						$bTag->title = $val;
						$bTag->save();
					}
				}
				if ($request->id) {
					return response()->json(['status' => 1, 'message' => 'Blog Updated successfully', 'next' => 'admin/blog/index']);
				}
				return response()->json(['status' => 1, 'message' => 'Blog created successfully', 'next' => 'admin/blog/index']);
			} else {
				return response()->json($validationResult);
			}
		}
	}
    
    public function view(Request $request)
    {
        $data = Blog::findOrFail($request->input('id'));
        if (!$data) {
            return response()->json(['status' => 0, 'message' => 'No data found']);
        }
        $blogCategory=BlogCategory::find($data->blog_category_id);
        return view('admin/blog/view', compact('data','blogCategory'));
    }

    public function delete(Request $request)
    {
        $model = Blog::find($request->input('id'));
        if (!$model) {
            return response()->json(['status' => 0, 'message' => 'No data found']);
        }
        $model->delete();
        return response()->json(['status' => 1, 'message' => 'Data Deleted successfully.', 'next' => 'refresh']);
    }
}
