<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\Room;
use App\Helper\General;
class RoomController extends Controller
{
    public function index()
    {
        return view('admin/room/index');
    }

    public function list(Request $request)
    {
        return response()->json((new Room())->list($request->all()));
    }

    public function create()
    {
        
        $oldImages = '';
        return view('admin/room/create', compact('oldImages'));
    }

    public function update(Request $request)
    {
        $room = Room::find($request->id);
        if(!$room){
            return redirect('admin/room')->withError('error','No data found');
        }
        $imageArray = explode(',', $room->images);
        $fullArray = [];
        foreach ($imageArray as $key => $data) {
            $fullArray[$key] = [
                'name' => $data,
                'url' => (new General())->getFileUrl($data, 1)
            ];
        }
        $oldImages = json_encode($fullArray);
        return view('admin/room/update', compact('room','oldImages'));
    }

    public function save(Request $request)
    {
        // dd($request->all());
        $id = $request->input('id');
        $rules=[
            'visit_id' => 'required',
            'title' => 'required',
            'description' =>'required',
            'image'=>'mimes:jpeg,jpg,png,gif,webp|max:10000',
            'check' => 'required',
            'adults' => 'required',
            'price' => 'required',
        ];
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return response()->json(['status' => 0, 'message' => $this->general->getError($validator)]);
        }
        $id = $request->id;
        if ($id) {
            $room = Room::find($id);
        } else {
            $room = new Room();
        }
       
        if ($request->hasFile('main_image')) {
            $main_image = $this->general->upload($request->file('main_image'), 1);
            if ($main_image) {
                if ($room->image) {
                    $this->general->deleteFile($room->image, 1);
                }
                $room->main_image = $main_image;
            }
        }

        $imageArray = [];
       // dd($imageArray);
        if ($request->hasFile('images')) {
            $plateImage = $request->file('images');
            $oldFileCount = 0;
            if (isset($request->file_old)) {
                $oldFileCount = count($request->file_old);
            }

            $newFileCount = count($plateImage);
            if (($oldFileCount + $newFileCount) > 50) {
                return response()->json(['status' => 0, 'message' => 'Max 50 files allowed']);
            }

            foreach ($plateImage as $imageKey => $image) {
                $image = $this->general->upload($image, 1);
                if ($image) {
                    $imageArray[$imageKey] = $image;
                    $oldFileCount++;
                }
            }
        }
        $oldImages = [];
        if ($room->images) {
            $plateImage =  explode(",", $room->images);
            if ($request->file_old) {
                $imageArray = array_merge($request->file_old, $imageArray);
                $removedImages = array_diff($plateImage, $request->file_old);
                foreach ($removedImages as $img) {
                    $this->general->deleteFile($img, 1);
                }
            } else {
                foreach ($plateImage as $imges) {
                    $this->general->deleteFile($imges, 1);
                }
            }
        }
        $room->images = implode(',', $imageArray);
        $array = $request->input('check');
        $room->title = $request->input('title');
        $room->visit_id = $request->input('visit_id');
        $room->description = $request->input('description');
        $room->price = $request->input('price');
        $room->adults = $request->input('adults');
        $room->child = $request->input('child');
        $room->feature = $request->input('check');
        $room->feature = implode(',',$array);
        // $room->status = $request->input('status')
       //dd($room);
        $room->save();

        return response()->json(['status' => 1, 'message' => $id?'Room Data Updated successfully.':'Room Data Created successfully.', 'next' => 'admin/room']);
    }
    public function view(Request $request)
    {
        $room = Room::find($request->input('id'));
        if(!$room){
            return redirect('admin/room')->withError('error','No data found');
        }
        return view('admin/room/view', compact('room'));
    }

    public function delete(Request $request)
    {
        $room = Room::find($request->input('id'));
        if (!$room) {
            return response()->json(['status' => 0, 'message' => 'No data found']);
        }
        $room->delete();
        return response()->json(['status' => 1, 'message' => 'Data Deleted successfully.', 'next' => 'table_refresh']);
    }
}
