<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use DateTimeZone;
use App\Models\Setting;
use Illuminate\Support\Facades\Validator;

class SettingController extends Controller
{
    public function update(Request $request)
	{
        $setting=$this->general->getAllSettings();
        $timezonelist = DateTimeZone::listIdentifiers(DateTimeZone::ALL);
		return view('admin/setting/update',['setting'=>$setting,'timezonelist'=>$timezonelist]);
	}

    public function save(Request $request){
        $validator =Validator::make($request->all(),[
			'app_name' => 'required',
            'date_format'=>'required',
            'date_time_format'=>'required',
            'timezone' => 'required',
            'user_email_verify'=>'required',
            'social_login'=>'required',
            'user_login_with_otp'=>'required',
            'admin_email'=>'required',
		]);
		if ($validator->fails()) {
		    return response()->json(['status'=>0,'message'=>$this->general->getError($validator)]);
		}
        $setting=[
            'app_name'=>$request->input('app_name'),
            'date_format'=>$request->input('date_format'),
            'date_time_format'=>$request->input('date_time_format'),
            'timezone'=>$request->input('timezone'),
            'user_email_verify'=>$request->input('user_email_verify'),
            'user_login_with_otp'=>$request->input('user_login_with_otp'),
            'admin_email'=>$request->input('admin_email'),
        ];
        (new Setting())->updateAll($setting);
        return response()->json(['status'=>1,'message'=>'data saved successfully','next'=>'nothing']);
    }

    public function saveFile(Request $request){
        $validator =Validator::make($request->all(),[
			'key' => 'required',
		]);
		if ($validator->fails()) {
		    return response()->json(['status'=>0,'message'=>$this->general->getError($validator)]);
		}
        $key=$request->key;
        $file=$request->file($key);
       
        if($file){
            $validator =Validator::make($request->all(),[
                $key  =>  'file|image|mimes:jpg,jpeg,png|max:2048'
            ]);
            if ($validator->fails()) {
                return response()->json(['status'=>200,'code'=>0,'message'=>'File is not valid']); 
            }
            $fileName=$this->general->upload($file,2);
            if($fileName){
                $setting=Setting::where(['key'=>$key])->first();
                if($setting ){
                    //todo : delete old file
                    $setting->value=$this->general->getFileUrl($fileName,2);
                    $setting->save();
                    $setting->clearCache();
                }
            }
        }
        return response()->json(['status'=>1,'message'=>'data saved successfully','next'=>'nothing']);
    }

    public function cacheClear(Request $request)
	{
        (new Setting())->clearCache();
        return redirect('admin/setting/update')->with('success','Setting cache cleared');
	}

    public function smtp(Request $request){
        $validator =Validator::make($request->all(),[
			'host' => 'required',
            'username' => 'required',
            'password' => 'required',
            'encryption' => 'required',
            'port' => 'required',
            'mail_from_address' => 'required',
            'mail_from_name' => 'required',
        ]);
		if ($validator->fails()) {
		    return response()->json(['status'=>0,'message'=>$this->general->getError($validator)]);
		}
        $setting=[
            'host'=>$request->input('host'),
            'username'=>$request->input('username'),
            'password'=>$request->input('password'),
            'encryption'=>$request->input('encryption'),
            'port'=>$request->input('port'),
            'mail_from_address'=>$request->input('mail_from_address'),
            'mail_from_name'=>$request->input('mail_from_name'),
        ];
        (new Setting())->updateAll($setting);
        return response()->json(['status'=>1,'message'=>'data saved successfully','next'=>'nothing']);

    }
    
    public function captcha(Request $request)
    {
        $validator =Validator::make($request->all(),[
            'google_recaptcha'=>'required',
            'google_recaptcha_secret_key'=>'required',
            'google_recaptcha_public_key'=>'required',
        ]);
        if ($validator->fails()) {
            return response()->json(['status'=>0,'message'=>$this->general->getError($validator)]);
        }
        $setting=[
            'google_recaptcha'=>$request->input('google_recaptcha'),
            'google_recaptcha_secret_key'=>$request->input('google_recaptcha_secret_key'),
            'google_recaptcha_public_key'=>$request->input('google_recaptcha_public_key'),

        ];
        (new Setting())->updateAll($setting);
        return response()->json(['status'=>1,'message'=>'data saved successfully','next'=>'nothing']);
    }
    
    public function social(Request $request)
    {
        $setting=[
            'google_client_id'=>$request->input('google_client_id'),
            'google_client_secret'=>$request->input('google_client_secret'),
            'google_login'=>$request->input('google_login'),

        ];
        (new Setting())->updateAll($setting);
        return response()->json(['status'=>1,'message'=>'data saved successfully','next'=>'nothing']);
    }
    
    public function content(Request $request)
    {
        $setting=[
            'header_content'=>$request->input('header_content'),
            'footer_content'=>$request->input('footer_content'),

        ];
        (new Setting())->updateAll($setting);
        return response()->json(['status'=>1,'message'=>'data saved successfully','next'=>'nothing']);
    }
    
    public function payment(Request $request)
    {
        $setting=[
            'stripe_enable'=>$request->input('stripe_enable'),
            'stripe_secret_key'=>$request->input('stripe_secret_key'),
            'stripe_public_key'=>$request->input('stripe_public_key'),

        ];
        (new Setting())->updateAll($setting);
        return response()->json(['status'=>1,'message'=>'data saved successfully','next'=>'nothing']);
    }
    
}
