<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

use App\Models\Conversation;
use App\Models\Message;
use App\Models\User;

class MessageController extends Controller
{
    public function chat(Request $request)
    {
        $userId = auth()->id();
        $conversationModel = new Conversation();
        if (!$conversationModel->checkConv($userId)) {
            return view('message.blank');
        }
        return view('message/chat');
    }

    public function start(Request $request)
    {
        if (!auth()->check()) {
            return redirect('login')->with('error', 'Please First Login');
        }
        $from_id = auth()->id();
        $conversationId = '';
        $to_id = $request->input('id');
        $reference_id = $request->input('reference_id');
        if (!$to_id) {
            session()->flash('error', 'Invalid request!');
            return redirect('/');
        }

        $conversation = Conversation::where(function ($query) use ($from_id, $to_id, $reference_id) {
            $query->where('from_user_id', $from_id)
                ->where('to_user_id', $to_id)
                ->where('reference_id', $reference_id);
        })->orWhere(function ($query) use ($from_id, $to_id, $reference_id) {
            $query->where('to_user_id', $from_id)
                ->where('from_user_id', $to_id)
                ->where('reference_id', $reference_id);
        })->first();

        if ($conversation) {
            $conversationId = $conversation->id;
        } else {
            $user = User::find($to_id);

            if (!$user) {
                session()->flash('error', 'Invalid request!');
                return redirect('/');
            }

            if ($from_id == $to_id) {
                session()->flash('error', 'Please try to diffrent plate');
                return redirect('/');
            }

            $conversationData = [
                'from_user_id' => $from_id,
                'to_user_id' => $to_id,
                'reference_id' => $reference_id,
                'created_at' => now(),
            ];

            $newConversation = Conversation::create($conversationData);
            $conversationId = $newConversation->id;
        }
        if (isset($conversationId)) {
            if (isset($request->message)) {
                $conversationData = Conversation::find($conversationId);
                $messageModel = new Message();
                $messageData = [
                    'message' => $request->message,
                    'conversation_id' => $conversationId,
                    'from_user_id' => $conversationData->from_user_id,
                    'to_user_id' => $conversationData->to_user_id,
                    'type' => 0,
                    'created_at' => time(),
                ];
                $messageModel->insert($messageData);
            }
        }


        return redirect()->to(route('message/chat', ['id' => $conversationId]));
    }

    public function conversationList()
    {
        $id = auth()->id();
        $convModel = new Conversation();
        $messageModel = new Message();
        $data = $convModel->getConversationList($id);
        foreach ($data as $key => $row) {
            $opponentId = ($row->from_user_id == $id) ? $row->to_user_id : $row->from_user_id;
            $data[$key]->message = $messageModel->messageHtml($row, $id);
            $data[$key]->message_text = $messageModel->messageText($row, $id);
            $data[$key]->count_unread_msg = $messageModel->getConversationUnreadCount($opponentId, $id);
            $data[$key]->created_at = date(config('setting.date_format'), $row->created_at) . ' | ' . date('h:i A', $row->created_at);
            $data[$key]->image = ($row->image) ? (new General())->getFileUrl($row->image, 1) : '';
            $data[$key]->reference_id = $row->reference_id;
        }
        return response()->json(['status' => 1, 'data' => $data]);
    }



    public function conversationDetail(Request $request)
    {
        $id = auth()->id();
        $convId = $request->input('conv_id');
        $convModel = new Conversation();
        $userModel = new User();
        $data = $convModel->where('id', $convId)->first();
        $referenceId = $data->reference_id;

        // if ($referenceId) {
        //     $plateModel = new Plate();
        //     $plate = $plateModel->where('id', $referenceId)->first();
        //     $toId = $plate->user_id;

        //     $plateStatus = $plateModel->getStatus($plate->status);

        //     $plateHtml = view('message.plate', ['plate' => $plate, 'plateStatus' => $plateStatus])->render();
        // } else {
        //     $plateHtml = view('message.plate')->render();
        // }
        $detailHtml='';

        if ($data && ($data->from_user_id == $id || $data->to_user_id == $id)) {
            $opponantId = $data->from_user_id == $id ? $data->to_user_id : $data->from_user_id;
            $opponant = $userModel->where('id', $opponantId)->first();

            $chatHeaderHtml = view('message.header', ['opponant' => $opponant, 'referenceId' => $referenceId])->render();

            return response()->json(['status' => 1, 'data' => ['opponantId' => $opponantId, 'chatHeaderHtml' => $chatHeaderHtml, 'detailHtml' => $detailHtml]]);
        } else {
            return response()->json(['status' => 0, 'message' => 'No data']);
        }
    }

    public function history(Request $request)
    {
        $user = auth()->user();
        $id = $user->id;
        $convId = $request->input('conv_id');
        $messageModel = new Message();
        $data = $messageModel->getHistory($convId);
        $messageList = [];
        foreach ($data as $key => $row) {
            $messageList[$key] = $messageModel->setData($row, $id);
        }

        $data = array_reverse($messageList);

        return response()->json(['status' => 1, 'data' => $data]);
    }

    public function readStatus(Request $request)
    {
        $convId = $request->input('conv_id');
        $id = auth()->id();

        $convModel = new Conversation();
        $messageModel = new Message();

        $convData = $convModel->where('id', $convId)->firstOrFail();
        $opponentId = ($convData->from_user_id == $id) ? $convData->to_user_id : $convData->from_user_id;

        $messageModel->where('conversation_id', $convId)
            ->where('from_user_id', $opponentId)
            ->where('to_user_id', $id)
            ->update(['status' => 1]);

        return response()->json(['status' => 1, 'message' => 'success']);
    }

    public function send(Request $request)
    {
        $user = auth()->user();
        $id = $user->id;
        $convId = $request->input('conv_id');

        $message = $request->input('message');
        $type = $request->input('type', 0);
        $data = $request->input('data') !== '' ? json_encode($request->input('data')) : '';

        $convModel = new Conversation();
        $messageModel = new Message();
        $userModel = new User();

        $convData = $convModel->where('id', $convId)->first();

        if (!empty($convData)) {
            $opponentId = ($convData->from_user_id == $id) ? $convData->to_user_id : $convData->from_user_id;
            $opponent = $userModel->where('id', $opponentId)->first();

            $messageData = [
                'message' => ($message) ? $message : ' ',
                'conversation_id' => $convId,
                'from_user_id' => $id,
                'to_user_id' => $opponentId,
                'type' => $type,
                'data' => $data,
                'created_at' => time(),
            ];

            $messageModel->insert($messageData);
            $lastMessageId = $messageModel->latest()->first()->id;
            $convModel->where('id', $convId)->update(['last_message_id' => $lastMessageId, 'updated_at' => time()]);

            $messageData['id'] = $lastMessageId;
            $meMessage = $messageModel->setData((object)$messageData, $id);

            $opponentMessage = $messageModel->setData((object)$messageData, $opponentId);

            return response()->json(['status' => 1, 'data' => $meMessage, 'opponentMessage' => $opponentMessage]);
        }

        return response()->json(['status' => 0, 'message' => 'No Conversation yet']);
    }

    public function uploadFile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'file' => 'required|file|mimes:jpeg,png,pdf,jpg,doc,docx,xls,xlsx,zip,wav,mp4,webp|max:2048', // Adjust max file size as needed
        ]);

        if ($validator->fails()) {
            return response()->json([
                'status' => 0,
                'message' => 'File validation failed',
                'errors' => $validator->errors(),
            ]);
        }

        if ($request->hasFile('file')) {
            $uploadedFile = $request->file('file');
            $path = $this->general->chatImageupload($request->file('file'), 5); // Adjust the storage path and disk as needed

            return response()->json([
                'status' => 1,
                'message' => 'File uploaded successfully',
                'path' => $path,
            ]);
        }

        return response()->json([
            'status' => 0,
            'message' => 'File not found in the request',
        ]);
    }
}
