<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\Device;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProfileController extends Controller
{

    public function update(Request $request)
    {
        $model = auth()->user();
        return view('profile/update', compact('model'));
    }

    public function save(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'first_name' => 'required',
            'last_name' => 'required',
            'email' =>  'required|email|required|regex:/(.+)@(.+)\.(.+)/i',
        ]);
        if ($validator->fails()) {
            return response()->json(['status' => 0, 'message' => $this->general->getError($validator)]);
        }

        $model = auth()->user();
        $model->first_name = $request['first_name'];
        $model->last_name = $request['last_name'];
        $model->email = $request['email'];
        $model->save();
        return response()->json(['status' => 1, 'message' => 'Profile updated successfully', 'next' => 'refresh']);
    }

    public function passwordChange(Request $request)
    {
        $model = auth()->user();
        return view('profile/change_password', compact('model'));
    }

    public function changePasswordProcess(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'current_password' =>  'required',
            'password' => 'required|min:6|max:20',
            'confirm_password' => 'required|min:6|max:32|same:password',
        ]);
        if ($validator->fails()) {
            return response()->json(['status' => 0, 'message' => $this->general->getError($validator)]);
        }
        $model = auth()->user();
        if($request->input('current_password')){

        }
        $model->password=$model->encryptPassword($request['confirm_password']);
        $model->save();

        return response()->json(['status' => 1, 'message' => 'Password updated successfully', 'next' => 'refresh']);
    }

    public function image()
    {
        $model = auth()->user();
        return view('profile/image', compact('model'));
    }

    public function imageSave(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'image' => 'file|image|mimes:jpg,jpeg,png|max:12400',
        ]);
        if ($validator->fails()) {
            return response()->json(['status' => 0, 'message' => $this->general->getError($validator)]);
        }
        $model = auth()->user();
        $fileName = $this->general->upload($request->file('image'));
        if ($fileName) {
            if($model->image){
                $this->general->deleteFile($model->image);
            }
            $model->image = $fileName;
            $model->save();
            return response()->json(['status' => 1, 'message' => 'Profile updated successfully', 'next' => 'reload']);
        } else {
            return response()->json(['status' => 1, 'message' => 'unsuccessfully']);
        }
    }

    public function logout(Request $request){
        (New Device())->forceLogout($request->input('id'));
        return response()->json(['status' => 1, 'message' => 'Logged out successfully', 'next' => 'reload']);
    }

}
