<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Tfa;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Session;

class TfaController extends Controller
{
    public function index(Request $request)
	{
	    
	    $user=auth()->user();
        $tfa = Tfa::where(['user_id'=>$user->id])->get();
        return view('tfa/index',compact('tfa','user'));
	}

    public function save(Request $request)
    {
        $userId=auth()->id();
        $validator = Validator::make($request->all(), [
            'email' =>  'required|email|required',
        ]);
        if ($validator->fails()) {
            return response()->json(['status' => 0, 'message' => $this->general->getError($validator)]);
        }
        $email = $request->input('email');
        $tfa = Tfa::where(['receiver'=>$email,'user_id'=>$userId])->first();
        if($tfa){
            return response()->json(['status' => 0, 'message' => 'Email already exist']);
        }
        $tfa = new Tfa();
        $tfa->receiver = $email;
        $tfa->user_id = $userId;
		$tfa->save();
		$tfa->sendOtp($tfa);
		return response()->json(['status'=>1,'next'=>'tfa/verify-status?id='.$tfa->id,'message'=>'OTP successfully sended to your email']);
    }

    public function verifyStatus(Request $request)
	{
        $tfa = Tfa::where(['id'=>$request->input('id'),'user_id'=>auth()->id()])->first();
        return view('tfa/verify_status',compact('tfa'));
	}

    public function verifyProcess(Request $request){
        if ($this->general->rateLimit('tfa-enable-resend:' . $this->general->getClientIp())) {
			return redirect()->back()->with('error', 'Too many attempts please try after some time.')->withInput();
		}
        $validator = Validator::make($request->all(),[
			'verify_otp' => 'required',
		]);
		if ($validator->fails()) {
			return response()->json(['status'=>0,'message'=>$this->general->getError($validator)]);
		}
		$userId=auth()->id();
		$otp = $request->input('verify_otp');
        $tfa = Tfa::where(['id'=>$request->input('id'),'user_id'=>$userId])->first();
		if($tfa){
            $otpResult=$tfa->checkOtp($tfa,$otp);
            // dd($otpResult['status']);
            if($otpResult['status']) {
                $tfa->code = $tfa->generateOtp();
                if($request->input('verify_type')){
                    $tfa->status = 1;
                    Session::forget('verify_tfa'); 
                }
                $tfa->save();
                if($request->input('skip_tfa')){
                    $ignoredTfaDevices = [];
                    $user = User::where(['id'=>$userId])->first();
                    $igdevices = explode(',',$user['ignore_2fa_device']);
                    $ignoredTfaDevices = $igdevices;
                    if(!in_array($_COOKIE['dtoken'],$igdevices)){
                        $ignoredTfaDevices[] = $_COOKIE['dtoken'];
                        $user->ignore_2fa_device = implode(',',$ignoredTfaDevices);
                        $user->save();
                    }   
                }
                return response()->json(['status'=>1,'message'=>'Otp verify successfully','next'=>'tfa']);
            }else{
                return ['status' => 0, 'message' => $otpResult['message']];
            }
		}else{
		    return response()->json(['status' => 0, 'message' => 'This email is not valid']);
		}
    }
    
    public function delete(Request $request)
    {
        $tfa = Tfa::find(['id'=>$request->input('id'),'user_id'=>auth()->id()])->first();
        if ($tfa) {
            $tfa->delete();
            return response()->json(['status'=>1,'next'=>'refresh','message'=>'Delete successfully']);
        }else{
            return ['status' => 0, 'message' => 'Something went wrong'];
        }
    }
    
    public function enable(){
        $user=auth()->user();
        // dd($user);
        $user->status_tfa=1;
        $user->save();
        return response()->json(['status'=>1,'next'=>'tfa','message'=>'Two Factor Authentication is enabled']);
    }
    
    public function disable(){
        $user=auth()->user();
        $user->status_tfa=0;
        $user->save();
        return response()->json(['status'=>1,'next'=>'tfa','message'=>'Two Factor Authentication is disabled']);
    }
    
    public function resend(Request $request){
        
        $tfa = Tfa::where(['id'=>$request->input('id'),'user_id'=>auth()->id()])->first();
        $tfa->sendOtp($tfa);
    	return response()->json(['status'=>1,'message'=>'Otp resend successfully','next'=>'nothing']); 
    }

    /**login verify  */
    public function verify(Request $request)
	{
        $id = session('user_id');
	    $tfa = Tfa::where(['user_id'=>$id,'status'=>1])->get();
	   // dd($tfa);
        return view('tfa/verify',compact('tfa'));
	}
	
}      
