<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use App\Helper\Pagination;
use App\Helper\General;
use Illuminate\Support\Facades\DB;

class Conversation extends Model
{
    protected $table = 'conversation';
    protected $primaryKey = 'id';
    public $timestamps = true;
    protected $dateFormat = 'U';

    protected $fillable = [
        'from_user_id','to_user_id','plate_id','last_message_id','status','created_at','updated_at'
    ];
    
    public function getConv($from, $to, $plate)
    {
        return DB::table('conversation')
            ->where(function ($query) use ($from, $to, $plate) {
                $query->where('from_user_id', $from)
                    ->where('to_user_id', $to)
                    ->where('plate_id', $plate);
            })
            ->orWhere(function ($query) use ($from, $to, $plate) {
                $query->where('to_user_id', $from)
                    ->where('from_user_id', $to)
                    ->where('plate_id', $plate);
            })
            ->first();
    }
    
    public function checkConv($id)
    {
        return DB::table('conversation')
            ->where('from_user_id', $id)
            ->orWhere('to_user_id', $id)
            ->first();
    }
    
    public function getConversationList($id)
{
    return DB::table('conversation')
        ->select(
            'conversation.id as conv_id',
            'conversation.plate_id',
            'user.id as user_id',
            'user.image',
            DB::raw('CONCAT(user.first_name, " ", user.last_name) as name'),
            'message.created_at',
            'message.message',
            'message.data',
            'message.type',
            'message.status',
            'conversation.from_user_id',
            'conversation.to_user_id'
        )
        ->join('user', function ($join) use ($id) {
            $join->on(function ($query) use ($id) {
                $query->on('conversation.from_user_id', '=', DB::raw($id))
                    ->orOn('conversation.to_user_id', '=', DB::raw($id));
            });
            $join->on('user.id', '=', DB::raw('IF(conversation.from_user_id = ' . $id . ', conversation.to_user_id, conversation.from_user_id)'));
        })
        ->leftJoin('message', 'message.id', '=', 'conversation.last_message_id')
        ->where(function ($query) use ($id) {
            $query->where('conversation.from_user_id', $id)
                ->orWhere('conversation.to_user_id', $id);
        })
        ->orderBy('conversation.updated_at', 'desc')
        ->get();
}
}
