<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use App\Helper\Pagination;
use App\Helper\General;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class Message extends Model
{
    use HasFactory;

    protected $table = 'message';
    protected $primaryKey = 'id';
    protected $fillable = [
        'conversation_id', 'from_user_id', 'reference_id','to_user_id', 'message', 'status', 'type', 'data', 'created_at',
    ];
    public $timestamps = false;



    public function getHistory($convId)
    {
        return Message::where('conversation_id', $convId)
            ->orderBy('id', 'desc')
            ->get();
    }
    
    public function getUnreadCount($userId)
    {
        return Message::where('to_user_id', $userId)
            ->where('status', 0)
            ->count();
    }
    
    public function getConversationUnreadCount($opponentId, $userId)
    {
    return Message::where('from_user_id', $opponentId)
        ->where('to_user_id', $userId)
        ->where('status', 0)
        ->count();
    }
    
     public  function setData($message, $userId)
    {
        return [
            'id' => $message->id,
            'conversation_id' => $message->conversation_id,
            'from_user_id' => $message->from_user_id,
            'to_user_id' => $message->to_user_id,
            'created_at' => date(config('setting.date_format'),$message->created_at).' | '.
            date('h:i A',$message->created_at),
            'message' => self::messageHtml($message, $userId),
            'message_text' => self::messageText($message, $userId),
            'message_class' => $message->from_user_id == $userId ? 'right-msg' : 'left-msg',
            'type' => $message->type,
            'message_type' => $message->type == 1 ? 'file' : 'msg',
        ];
    }
    
     public  function messageHtml($message, $userId)
    {
       
        $msg = $message->message ?? '';
        if ($message->type) {
            $msg = '';
            $data = json_decode($message->data, true);
            if ($data) {
                if (strpos($data['type'], 'image') !== false) {
                    $msg .= '<img src="' . (new General())->getFileUrl($data['file_name'], 5) . '">';
                } elseif (strpos($data['type'], 'mp3') !== false) {
                    $msg .= '<audio controls src="' . (new General())->getFileUrl($data['file_name'],5) . '"></audio>';
                } else {
                    $msg .= '<span style="padding:30px;"><i class="fa fa-file" style="font-size:100px;"></i></span><br>';
                }
                $msg .= '<a Download href="' . (new General())->getFileUrl($data['file_name'],5) . '">
                <i class="fa-solid fa-download"></i> ' . $data['name'] . '</a>';
                
            }
        }

        return $msg;
    }
    
    public  function messageText($message, $userId)
    {
        $msg = $message->message ? $message->message : '';

        if ($message->type) {
            $msg = '[File]';
        }

        if ($msg && $userId == $message->from_user_id) {
            $msg = 'Me: ' . $msg;
        }

        return $msg;
    }


}