<?php

namespace App\Models;

use App\Helper\General;
use App\Helper\Pagination;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\Eloquent\Model;

class Tfa extends Model
{
    protected $table = 'tfa';
    protected $primaryKey = 'id';
    public $timestamps = true;
    protected $dateFormat = 'U';

    protected $fillable = [
       'type','user_id', 'receiver','code','expire_at','device_ignore'
    ];
    
    public function checkTfaStatus($user){
        if($user->status_tfa){
            $deviceUid=@$_COOKIE['dtoken'];
            if($deviceUid){
                $ignoredTfaDevices = explode(',',$user->ignore_2fa_device);
                if(in_array($deviceUid,$ignoredTfaDevices)){
                    return false;
                }
            }
            $tfa=self::where(['user_id'=>$user->id,'status'=>1])->first();
            if($tfa){
                return true;
            }
        }
        return false;
    }
    public function generateOtp()
    {
        return random_int(100000, 999999);
    }

    public function checkOtp($tfa,$otp)
    {
        if ($tfa->expire_at < time()) {
            return ['status' => 0, 'message' => 'Otp is expired'];
        } else if ($otp != $tfa->code) {
            return ['status' => 0, 'message' => 'Otp is invalid'];
        } else {
            return ['status' => 1, 'message' => 'success'];
        }
    }
    public function status($status){
        if($status==1){
           $status = '<span class="badge badge-success">Active</span>';
        }else if($status == 0){
            $status = '<span class="badge badge-danger">In-active</span>';
        }
        return $status;
    }

    public function sendOtp($tfa){
        $tfa->code =$tfa->generateOtp();
        $tfa->expire_at =time()+config('setting.token_expire_time');
        $tfa->save();
        $general=new General();
        $general->sendMail($this->receiver, 'Two Factor Authentication | ' . config('setting.app_name'), 'email/otp_twofactor', [
            'otp' => $tfa->code
        ]);
    }
}