<?php

namespace App\Models;

use App\Helper\General;
use App\Helper\Pagination;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Models\Log;
use App\Models\Tfa;

class User extends Authenticatable
{
    protected $table = 'user';
    protected $primaryKey = 'id';
    public $timestamps = true;
    protected $dateFormat = 'U';

    protected $fillable = [
        'first_name', 'last_name', 'email', 'password', 'password_reset_token',
        'remember_token', 'email_verified', 'type', 'country', 'timezone',
        'registered_ip','image', 'status', 'created_at', 'updated_at',
         'social_id', 'social_type', 'status_tfa', ' login_otp','ignore_2fa_device'
    ];

    protected $hidden = [
        'password', 'password_reset_token','remember_token', 'email_verified', 'login_otp',
    ];

    public function isAdmin(){
        return $this->type == 1 || $this->type == 0?true:false;
    }

    public function isSuperAdmin(){
        return $this->type == 0?true:false;
    }

    public function encryptPassword($password)
    {
        return \Illuminate\Support\Facades\Hash::make($password);
    }

    public function checkPassword($password, $encryptedPassword)
    {
        return \Illuminate\Support\Facades\Hash::check($password, $encryptedPassword);
    }

    public function generateToken()
    {
        return base64_encode(\Illuminate\Support\Str::random(32) . '_' . time());
    }

    
    public function checkTokenExpired($token)
    {
        $token = base64_decode($token);
        $token = explode('_', $token);
        $token = @$token[1];
        //dd([$token,time()-config('setting.token_expire_time'),$token < (time() - config('setting.token_expire_time'))]);
        return $token < (time() - config('setting.token_expire_time'));
    }

    public function generateOtp()
    {
        return random_int(100000, 999999);
    }

    public function checkOtp($otp, $loginOtp)
    {

        $loginOtp = explode('_', $loginOtp);
        $time = @$loginOtp[1];
        if ($time < (time() - config('setting.token_expire_time'))) {
            return ['status' => 0, 'message' => 'Otp is expired'];
        } else if ($otp != @$loginOtp[0]) {
            return ['status' => 0, 'message' => 'Otp is invalid'];
        } else {
            return ['status' => 1, 'message' => 'success'];
        }
    }

    public function getStatusBadge($status)
    {
        return $status == 1 ? '<span class="badge bg-success">Active</span>' : '<span class="badge bg-danger">Inactive</span>';
    }

    public function loginByAuthToken($authToken)
    {
        if(!$this->checkTokenExpired($authToken)){
            return ['status' => 0, 'message' => 'Login failed'];
        }
        if(config('setting.save_user_device')){
            $deviceObj=new Device();
            $device = $deviceObj->where(['remember_token' => $authToken, 'device_uid'=>@$_COOKIE['dtoken']])->where('remember_expire_at','>',time())->first();
            if ($device && $device->user_id) {
                $user=User::where(['id'=>$device->user_id,'status'=>1,'email_verified'=>1])->first();
                if($user){
                    Auth::guard()->login($user);
                    (new Log)->add($user->id, 2);
                    (new Device())->login($user->id);
                    return ['status' => 1, 'message' => 'Login success'];
                }
            }
        }else{
            $user=User::where(['remember_token'=>$authToken,'status'=>1,'email_verified'=>'1'])->first();
            if($user){
                Auth::guard()->login($user);
                (new Log)->add($user->id, 2);
                return ['status'=>1,'message'=>'Login success'];
            }
        }
        return ['status' => 0, 'message' => 'Login failed'];
    }

    public function loginProcess($postData)
    {
        // dd(1);
        $user = User::where(['email' => $postData['email']])->first();
        if (!$user) {
            return ['status' => 0, 'message' => 'Email or password is not valid'];
        }
        if ($user->status == 0) {
            return ['status' => 0, 'message' => 'Your Account is blocked'];
        }
        if ($user->login_attempt >= config('setting.login_max_attempt') && $user->login_attempt_time > (time() - config('setting.login_ban_time'))) {
            return ['status' => 0, 'message' => 'Max login attempt exceed. Please Try after ' . ceil((config('setting.login_ban_time') - (time() - $user->login_attempt_time)) / 60) . ' Minutes'];
        }
        
        if (!$this->checkPassword($postData['password'], $user->password)) {
            $user->update([
                'login_attempt' => $user->login_attempt + 1,
                'login_attempt_time' => time(),
            ]);

            (new Log())->add($user->id, 0);
            // (new general)->sendMail($user->email, 'Password Confirmation | ' . config('setting.app_name'), 'email/login_password_alert', [
            // 	'name' => $user->first_name . ' ' . $user->last_name,
            // 	'url' => route('login-process')
            // ]);
            return ['status' => 0, 'message' => 'Email or password is not valid'];
        }

        if ($user->email_verified != '1') {
            return ['status' => 0, 'message' => 'Please verify your email, <a class="noroute" href="' . route('resend-email-verification', ['code' => base64_encode($user->email)]) . '">Click here</a> to verify your email address.'];
        }

        $activityObj = new Log();
        $activityObj->sendNewDeviceMail($user);
        $activityObj->add($user->id, 1);

        if ($user->login_attempt) {
            $user->update([
                'login_attempt' => 0,
            ]);
        }

        Auth::guard()->login($user);

        if(config('setting.save_user_device')){
            (new Device())->login($user->id,@$postData['remember']);
        }else{
            if(isset($postData['remember'])){
                $auth_token=$this->generateToken();
                $user->update([
                    'remember_token'=>$auth_token,
                ]);
                \Illuminate\Support\Facades\Cookie::queue('user_remember_token', $auth_token, 60 * 24 * 30);
            }
        }

        if((new Tfa())->checkTfaStatus($user)){
            session(['verify_tfa' => 1,'user_id' => $user['id']]);
        }
        
        return ['status' => 1, 'message' => 'Login success','user'=>$user];
    }

    public function sendLoginOtp($user){
        $otp=$this->generateOtp();
        $user->login_otp=$otp. '_' . time();
        $user->save();
        (new General())->sendMail($user->email, 'Login Otp | ' . config('setting.app_name'), 'email/otp_login', [
            'name' => $user->first_name . ' ' . $user->last_name,
            'otp' => $otp,
        ]);
    }

    public function registerProcess($postData)
    {
        $general = new General();
        $ip = $general->getClientIp();
        $ipInfo = $general->getIpInfo($ip);

        $userObj = new User();
        $user = $userObj->create([
            'first_name' => $postData['first_name'],
            'last_name' => $postData['last_name'],
            'email' => $postData['email'],
            'password' => $userObj->encryptPassword($postData['password']),
            'email_verified' => config('setting.user_email_verify') ? $userObj->generateToken() : 1,
            'registered_ip' => $ip,
            'country' => isset($ipInfo->country_name) ? $ipInfo->country_name : '',
            'timezone' => config('app.timezone')
        ]);
        $user->save();

        (new Log())->add($user->id, 3);

        if (config('setting.user_email_verify')) {
            $general->sendMail($user->email, 'Email Verify | ' . config('setting.app_name'), 'email/email_verify', [
                'name' => $user->first_name . ' ' . $user->last_name,
                'url' => route('email-verify', ['code' => $user->email_verified])
            ]);
            return ['status' => 1, 'message' => 'Thank you for registration, Please check your email to verify your account.'];
        }else{
            Auth::guard()->login($user);
            if(config('setting.save_user_device')){
                (new Device())->login($user->id,0);
            }
            (new Log())->add($user->id, 1);
        }
        return ['status' => 1, 'message' => 'Thank you for registration'];
    }

    public function listAdmin($postData)
    {
        $query = DB::table('user')->select('*')->where('type',1);
        /**/
        $searchText = isset($postData['search']['value']) ? $postData['search']['value'] : '';
        if (strlen($searchText) > 2) {
            $query->where("(concat(user.first_name,' ',user.last_name)", 'like', $searchText);
            $query->orWhere("user.email", 'like', $searchText);
        }
        /**/
        $userObj = new User();
        $result = (new Pagination())->getDataTable($query, $postData);
        foreach ($result['data'] as $key => $row) {
             $imageUrl = (new General())->getFileUrl($row->image ,1);
            if($row->image) {
                $result['data'][$key]->image = '<a href="upload/profile/' . $row->image . '" data-toggle="lightbox" data-title="Image" class = "noroute" target = "_blank">
                <img style="width:100px;height:100px" src="'.$imageUrl.'" class="img-fluid mb-2" alt="blog image"></a>';
            }
            $result['data'][$key]->first_name = $row->first_name . ' ' . $row->last_name;
            $result['data'][$key]->status = $userObj->getStatusBadge($row->status);
            $result['data'][$key]->created_at = date(config('setting.date_format'), $row->created_at);
            $result['data'][$key]->action = '<a href="admin/user/view?id=' . $row->id . '" class="btn btn-info btn-sm" title="View"><i class="fa fa-eye"></i></a>&nbsp;<a href="admin/user/update?id=' . $row->id . '" class="btn btn-info btn-sm" title="Update"><i class="fa fa-edit"></i></a>&nbsp;<button onclick="app.confirmAction(this);" data-action="admin/user/delete" data-id="' . $row->id . '" class="btn btn-danger btn-sm" title="Delete"><i class="fa fa-trash"></i></button>';
        }
        return $result;
    }
    
    public function list($postData)
    {
        $query = DB::table('user')->select('*')->where('type',2);
        /**/
        $searchText = isset($postData['search']['value']) ? $postData['search']['value'] : '';
        if (strlen($searchText) > 2) {
            $query->where("(concat(user.first_name,' ',user.last_name)", 'like', $searchText);
            $query->orWhere("user.email", 'like', $searchText);
        }
        /**/
        $userObj = new User();
        $result = (new Pagination())->getDataTable($query, $postData);
        foreach ($result['data'] as $key => $row) {
             $imageUrl = (new General())->getFileUrl($row->image ,1);
            if($row->image) {
                $result['data'][$key]->image = '<a href="upload/profile/' . $row->image . '" data-toggle="lightbox" data-title="Image" class = "noroute" target = "_blank">
                <img style="width:100px;height:100px" src="'.$imageUrl.'" class="img-fluid mb-2" alt="blog image"></a>';
            }
            $result['data'][$key]->first_name = $row->first_name . ' ' . $row->last_name;
            $result['data'][$key]->status = $userObj->getStatusBadge($row->status);
            $result['data'][$key]->created_at = date(config('setting.date_format'), $row->created_at);
            $result['data'][$key]->action = '<a href="admin/user/view?id=' . $row->id . '" class="btn btn-info btn-sm" title="View"><i class="fa fa-eye"></i></a>&nbsp;<a href="admin/user/update?id=' . $row->id . '" class="btn btn-info btn-sm" title="Update"><i class="fa fa-edit"></i></a>&nbsp;<button onclick="app.confirmAction(this);" data-action="admin/user/delete" data-id="' . $row->id . '" class="btn btn-danger btn-sm" title="Delete"><i class="fa fa-trash"></i></button>';
        }
        return $result;
    }

    function getUserMonthlyChartData(){
        $monthList=['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul','Aug','Sep','Oct','Nov','Dec'];
        $month=date('n');
        $label=[];
        $labelIndex=[];
        for($i=1;$i<13;$i++){
            $mi=($month+$i)%12;
            // dd($mi);
            $labelIndex[]=$mi;
            // dd($labelIndex);
            $label[]=$monthList[($mi?$mi:12)-1];
            // dd($label);
        }
        
        $data=[];
        $result=DB::select('SELECT count(*) as total,MONTH(FROM_UNIXTIME(created_at)) as month FROM `user` where status=1 group by MONTH(FROM_UNIXTIME(created_at));');
        foreach($labelIndex as $i){
            $monthData=0;
            foreach($result as $r){
                if($r->month==$i){
                    $monthData=$r->total;
                }
            }
            $data[]=$monthData; 
        }
        return [
            'label'=>$label,
            'data'=>$data
        ];
    }
    function getUserYearlyChartData(){

    }
}
